from typing import List, Optional, TypeVar
from pydantic import BeforeValidator
from typing_extensions import Annotated

# 自定义注解，自动将None转换为空列表
T = TypeVar("T")
EmptyListIfNone = Annotated[Optional[List[T]], BeforeValidator(lambda v: [] if v is None else v)]


import asyncio
import time
from functools import wraps
from loguru import logger


def func_time_cost(step_name=None):
    """
    记录函数执行耗时，并支持指定步骤名称

    参数:
        step_name: 步骤名称，默认为函数名
    """

    def decorator(func):
        @wraps(func)  # 保留原函数元信息
        def wrapper(*args, **kwargs):
            nonlocal step_name
            step_name = step_name or func.__name__

            # 执行原函数并处理返回值
            result = None
            start_time = time.perf_counter()
            try:
                logger.debug(f"StepStart [{step_name}]")
                result = func(*args, **kwargs)

                # 检查是否为协程对象
                if asyncio.iscoroutine(result):

                    async def wrapped_coroutine():
                        try:
                            return await result
                        finally:
                            logger.debug(
                                f"StepTimeCost | [{step_name}][{time.perf_counter() - start_time:.6f}]秒"
                            )

                    return wrapped_coroutine()

                # 普通函数直接返回结果
                return result
            finally:
                # 普通函数在这里记录时间
                if not asyncio.iscoroutine(result):
                    logger.debug(
                        f"StepTimeCost | [{step_name}][{time.perf_counter() - start_time:.6f}]秒"
                    )

        return wrapper

    return decorator


class TimeCostTik:
    """
    用于记录连续时间点之间耗时的工具类。
    每次调用 `tik(name)` 会打印上一次调用到本次的时间差（阶段耗时），
    以及从初始化到当前的时间差（总耗时）。
    示例用法
    time_usage_tool = TimeUsageTool()
    time_usage_tool.tik("初始化")
    time.sleep(1)
    time_usage_tool.tik("阶段1")
    time.sleep(2)
    time_usage_tool.tik("阶段2")
    输出
    [初始化], 总耗时 0.500123 秒
    [阶段1], 阶段耗时 1.000456 秒, 总耗时 1.500579 秒
    [阶段2], 阶段耗时 2.000789 秒, 总耗时 3.501368 秒
    """

    def __init__(self, reqid: str):
        self._tik = None  # 上一次调用 tik 的时间
        self._start = None
        self.reqid = reqid

    def tik(self, name: str):
        """
        记录从上一次调用到本次的时间差（阶段耗时），
        并记录从初始化到当前的时间差（总耗时）。
        :param name: 标识当前阶段的名称
        """
        time_now = time.perf_counter()
        phase_cost = None
        if self._start is None:
            self._start = time_now
        total_cost = time_now - self._start

        if self._tik is not None:
            phase_cost = time_now - self._tik

        # 打印信息
        if phase_cost is not None:
            logger.debug(
                f"Reqid: {self.reqid} [{name}], 阶段耗时 {phase_cost:.3f} 秒, 总耗时 {total_cost:.3f} 秒"
            )
        else:
            logger.debug(
                f"Reqid: {self.reqid} [{name}], 总耗时 {total_cost:.3f} 秒"
            )  #  首次调用

        self._tik = time_now  # 更新上次调用时间为当前时间



import os
from prometheus_client import Histogram, Counter
from starlette.requests import Request
from starlette.middleware.base import BaseHTTPMiddleware
from typing import List, Optional


class RequestMonitorMiddleware(BaseHTTPMiddleware):
    def __init__(self, app, buckets: Optional[List[float]] = None):
        super().__init__(app)

        # 设置默认 buckets，如果用户未提供则使用默认值
        default_buckets = [0.1, 0.5, 1, 3, 5]
        self.buckets = buckets if buckets is not None else default_buckets

        # 动态创建 Histogram 指标，使用传入的 buckets
        self.request_duration = Histogram(
            "http_request_duration_seconds",
            "Request duration in seconds",
            ["uri", "pid"],
            buckets=self.buckets,
        )

        # 错误请求计数器
        self.error_requests = Counter(
            "http_error_requests", "error HTTP requests", ["uri", "status"]
        )

    async def dispatch(self, request: Request, call_next):
        # 规范化路径：去掉末尾的斜杠（根路径除外）
        path = request.url.path
        normalized_path = path.rstrip("/") if path != "/" else path

        # 使用动态创建的 Histogram 指标
        with self.request_duration.labels(uri=normalized_path, pid=os.getpid()).time():
            response = await call_next(request)

            # 记录错误请求
            if response.status_code >= 400:
                self.error_requests.labels(
                    uri=normalized_path, status=response.status_code
                ).inc()

            return response



import aiohttp

from huibiao_framework.client.data_model.model_resp_vo import ModelBaseRespVo
from huibiao_framework.client.data_model.qa_search_new import (
    SearchQaDto,
    SearchQaVo,
    ReadQaDto,
    AddDocVo,
    AddDocDto,
    ReadQaVo,
    DeleteDbDto,
    DeleteDbVo,
)
from huibiao_framework.config.config import ClientConfig


class KnowledgeQaSearchClientNew:
    def __init__(self, session: aiohttp.ClientSession):
        self.base_url = ClientConfig.SEARCH_URL
        self.headers = {"Content-Type": "application/json"}
        self.session = session

    async def add_qa(
        self,
        request_body: AddDocDto,
    ) -> AddDocVo:
        """
        异步添加QA对到知识库
        """
        url = f"{self.base_url}/data/add_doc"

        async with self.session.post(
            url, json=request_body.model_dump(), headers=self.headers
        ) as response:
            response.raise_for_status()
            raw_response = await response.json()
            return ModelBaseRespVo[AddDocVo](**raw_response).result

    async def delete_db(
        self,
        request_body: DeleteDbDto,
    ) -> DeleteDbVo:
        """
        异步添加QA对到知识库
        """
        url = f"{self.base_url}/data/delete_db"

        async with self.session.post(
            url, json=request_body.model_dump(), headers=self.headers
        ) as response:
            response.raise_for_status()
            raw_response = await response.json()
            return ModelBaseRespVo[DeleteDbVo](**raw_response).result

    async def search_qa(self, request_body: SearchQaDto) -> SearchQaVo:
        """
        异步搜索QA对
        """
        url = f"{self.base_url}/data/search"

        async with self.session.post(
            url, json=request_body.model_dump(exclude_none=True), headers=self.headers
        ) as response:
            response.raise_for_status()
            raw_response = await response.json()
            return ModelBaseRespVo[SearchQaVo](**raw_response).result


    async def read_qa(self, request_body: ReadQaDto) -> ReadQaVo:
        """
        异步搜索QA对
        """
        url = f"{self.base_url}/data/chunks/query_by_doc"

        async with self.session.post(
            url, json=request_body.model_dump(exclude_none=True), headers=self.headers
        ) as response:
            response.raise_for_status()
            raw_response = await response.json()
            return ModelBaseRespVo[ReadQaVo](**raw_response).result



import aiohttp

from huibiao_framework.client.llm import AbstractLlmModelClient
from huibiao_framework.client.llm.schema import MindleDs32bAwqDto, MindleDs32bAwqVo
from huibiao_framework.config.config import LlmModelNameConstant, ModelConfig


class MindleDs32bAwqClient(AbstractLlmModelClient):
    """
    curl --location --request POST 'http://mindie-ds-32b-awq.office.sh.ctyun.cn:9080/v1/chat/completions' \
    --header 'Content-Type: application/json' \
    --data-raw '{
        "model": "huize",
        "messages": [
            {
                "role": "user",
                "content": "你好"
            }
        ]
    }'

    响应
        {
        "id": "chatcmpl-ab718673ce220e43572b4055414a7362",
        "choices": [
            {
                "finish_reason": "stop",
                "index": 0,
                "message": {
                    "role": "assistant",
                    "content": "<think>\n\n</think>\n\n你好！很高兴见到你，有什么我可以帮忙的吗？无论是学习、工作还是生活中的问题，都可以告诉我哦！😊",
                    "function_call": null,
                    "tool_calls": []
                },
                "logprobs": null
            }
        ],
        "created": 1761207189,
        "model": "huize",
        "object": "chat.completion",
        "usage": {
            "prompt_tokens": 5,
            "total_tokens": 36,
            "completion_tokens": 31
        }
    }
    """

    def __init__(self, session: aiohttp.ClientSession, url: str = None):
        super().__init__(
            client_name=LlmModelNameConstant.MindileDs32bAwq, session=session, url=url
        )

    def cal_content_len(self, dto: MindleDs32bAwqDto):
        return [len(i.content) for i in dto.messages]

    async def query(
        self, dto: MindleDs32bAwqDto, session_id: str = ""
    ) -> MindleDs32bAwqVo:
        dto.model = ModelConfig.OPEN_AI_MODEL_TYPE
        resp_json = await self.post(dto=dto, session_id=session_id)
        return MindleDs32bAwqVo(**resp_json)

    async def simple_query(self, content, session_id: str = "", **kwargs) -> str:
        dto = MindleDs32bAwqDto()
        dto.messages.append(MindleDs32bAwqDto.Message(content=content))
        vo: MindleDs32bAwqVo = await self.query(dto=dto, session_id=session_id)
        assert vo.choices and vo.choices[0].message, f"响应数据为空:{vo.model_dump()}"
        return vo.choices[0].message.content



from typing import List

from miniopy_async.datatypes import Object as MinioObject
from datetime import datetime, timedelta
from loguru import logger

from huibiao_framework.client import MinIOClient
from huibiao_framework.config import MinioConfig


class OssOutdatedDirCleaner:
    """
    删除oss中过期的目录
    """

    def __init__(self, prefix: str, client: MinIOClient, retention_day: int = 30, theme: str = ""):
        self.prefix = prefix
        self.retention_day = retention_day
        self.theme = theme
        self.current_time: datetime = datetime.now()
        self.threshold_time: datetime = self.current_time - timedelta(
            days=self.retention_day
        )
        self.client: MinIOClient = client

    def thread_hold_time(self):
        return self.threshold_time

    async def do_clean(self):
        """
        开始清除
        """
        outdated_objs = await self.list_outdated_obj()
        logger.info(f"{self.theme} 开始清理缓存目录，共{len(outdated_objs)}个目录")
        failed = await self.batch_delete_obj(obj_list=outdated_objs, client=self.client)
        logger.info(f"{self.theme} 缓存目录清理完成，失败数{len(failed)}/{len(outdated_objs)}")


    def is_outdated(self, obj: MinioObject):
        if obj.object_name == self.prefix or obj.last_modified is None:
            return False
        return obj.last_modified < self.threshold_time

    async def list_outdated_obj(self) -> List[MinioObject]:
        """
        列出过期的oss key
        """
        result: List[MinioObject] = await self.client.list_objects(
            bucket_name=MinioConfig.BUCKET_NAME, prefix=self.prefix
        )
        outdated_obj_list = [r for r in result if self.is_outdated(r)]

        logger.debug(
            f"path={self.prefix}, threshold_time={self.threshold_time}, "
            f"retention_day={self.retention_day}, found outdated obj, {len(outdated_obj_list)}"
        )

        return outdated_obj_list

    @classmethod
    async def batch_delete_obj(cls, client: MinIOClient, obj_list: List[MinioObject]) -> List[MinioObject]:
        """
        批量并递归删除目录
        返回递归删除失败的对象
        """
        num = len(obj_list)
        failed = []
        for idx, obj in enumerate(obj_list):
            logger.debug(
                f"try to delete oss key [{idx + 1}]/[{num}]: {obj.object_name}"
            )
            try:
                errors = await client.remove_objects_by_prefix_recursive(
                    MinioConfig.BUCKET_NAME, obj.object_name
                )
                if errors:
                    logger.warning(
                        f"clean unclaimed oss key [{idx}]/[{num}]: {obj.object_name} exists error: {errors}"
                    )
                    failed.append(obj)
            except Exception as e:
                logger.error(
                    f"clean unclaimed oss key [{idx}]/[{num}]: {obj.object_name} error: {e}"
                )
                failed.append(obj)

        return failed


import uvicorn
from huibiao_framework.backend.metrics import PrometheusContext

from huibiao_framework.backend.log_utils import ServiceLoggerManager
from huibiao_framework.config import ServiceConfig


class HuibiaoServiceStarter:
    def __init__(self, service_name: str):
        self.service_name = service_name

    def setup_multi_process_metrics(self):
        # 初始化prometheus多进程的设置
        PrometheusContext.init()
        return self

    def setup_par_pid_log(self):
        # 多worker时，主进程的日志设置
        ServiceLoggerManager.setup_log(self.service_name)
        return self

    def setup_log_cleaner(self):
        # 启动定时任务清理日志
        ServiceLoggerManager.run_log_cleaner(self.service_name)
        return self

    def main_pid_setup(self):
        """
        主进程中的设置
        """
        self.setup_multi_process_metrics()
        self.setup_par_pid_log()
        self.setup_log_cleaner()
        return self

    @classmethod
    def run(
        cls,
        app_str: str = "app.backend.application:app",
        host: str = "0.0.0.0",
        **kwargs,
    ):
        # 启动服务
        uvicorn.run(
            app_str,
            host=host,
            port=ServiceConfig.HTTP_PORT,
            timeout_keep_alive=ServiceConfig.TIMEOUT_KEEP_ALIVE,
            workers=ServiceConfig.PROCESS_NUM,
            **kwargs,
        )



import aiohttp
from huibiao_framework.client.data_model.model_resp_vo import ModelBaseRespVo
from huibiao_framework.client.llm.abstrast_llm_client import AbstractLlmModelClient
from huibiao_framework.client.llm.schema import HuizeQwen32bAwqDto, HuizeQwen32bAwqVo
from huibiao_framework.config.config import LlmModelNameConstant


class HuiZeQwen32bQwqClient(AbstractLlmModelClient):
    """
    慧泽Qwen-32B模型客户端
    url: http://vllm-qwen-32b.model.hhht.ctcdn.cn:9080/common/query
    request:
        {
        "Action": "NormalChat",
        "DoSample": true,
        "Messages": [
                {
                    "content": "请将下面这段英文翻译成中文：请将下面这段英文翻译成中文：I am a test。",
                    "role": "user"
                }
            ]
        }
    response:
        {
            "code": 0,
            "result": {
                "Output": "我是一个测试。",
                "TokenProbs": [
                    1.0
                ]
            },
            "message": "success"
        }
    """

    def __init__(self, session: aiohttp.ClientSession, url: str = None):
        super().__init__(
            client_name=LlmModelNameConstant.HuiZeQwen32bAwq, session=session, url=url
        )

    def cal_content_len(self, dto: HuizeQwen32bAwqDto):
        return [len(i.content) for i in dto.Messages]

    async def query(
        self, dto: HuizeQwen32bAwqDto, session_id: str = ""
    ) -> ModelBaseRespVo[HuizeQwen32bAwqVo]:
        resp_json = await self.post(dto=dto, session_id=session_id)
        return ModelBaseRespVo[HuizeQwen32bAwqVo](**resp_json)

    async def simple_query(
        self, content, session_id: str = "", do_sample: bool = None, top_k: int = None
    ) -> str:
        dto = HuizeQwen32bAwqDto()

        dto.DoSample = do_sample
        dto.TopK = top_k

        dto.Messages.append(HuizeQwen32bAwqDto.Message(content=content))
        vo: ModelBaseRespVo[HuizeQwen32bAwqVo] = await self.query(dto, session_id)
        return vo.result.Output



from huibiao_framework.backend.status_code import (
    BasicStatusCode,
    BasicApiInnerErrorCode,
)
from typing import TypeVar


class BasicException(Exception):
    """
    基础异常类
    """

    def __init__(self, code: int, msg: str):
        super().__init__(msg)
        self.code = code
        self.msg = msg


# 定义泛型变量 T，限定为 BasicStatusCode 的子类
T = TypeVar("T", bound=BasicStatusCode)


class BasicCommonException(BasicException):
    def __init__(self, status_code: T, **kwargs):
        super().__init__(code=status_code.code, msg=status_code.msg.format(**kwargs))


# 定义泛型变量 ET，限定为 BasicApiInnerErrorCode 的子类
ET = TypeVar("ET", bound=BasicApiInnerErrorCode)


class BasicApiInnerException(BasicException):
    """
    接口内部异常类的基类
    """

    def __init__(self, status_code: ET, **kwargs):
        super().__init__(code=status_code.code, msg=status_code.msg.format(**kwargs))



from .status_code import (
    CommonStatusCode,
    BasicApiId,
    BasicApiInnerErrorCode,
    BasicStatusCode,
)
from .exception import BasicException, BasicCommonException, BasicApiInnerException
from .vo import BaseRespVo
from .handler import timing_and_exception_handler
from .error_code_manage import ApiErrorCodeManage, BasicCodeManage
from .metrics import PrometheusTimeCostMetricSetting

__all__ = [
    # 响应码
    "BasicApiId",
    "CommonStatusCode",
    "BasicApiInnerErrorCode",
    "BasicStatusCode",
    # 异常类
    "BasicException",
    "BasicCommonException",
    "BasicApiInnerException",
    # 响应类
    "BaseRespVo",
    # 装饰器
    "timing_and_exception_handler",
    "PrometheusTimeCostMetricSetting",
    # api错误码管理
    "ApiErrorCodeManage",
    "BasicCodeManage",
]



import threading
import time
from pydantic import BaseModel, Field
from typing import List, Optional
import os
from datetime import datetime, timedelta
from loguru import logger


class LogInfo(BaseModel):
    """
    日志信息
    """

    file_path: str = Field(..., description="日志文件路径")
    file_size: Optional[int] = None  # 日志文件大小
    create_time: Optional[datetime] = None  # 日志文件创建时间
    modify_time: Optional[datetime] = None  # 日志文件修改时间
    access_time: Optional[datetime] = None  # 日志文件访问时间

    @classmethod
    def gen(cls, file_path: str):
        if not os.path.exists(file_path):
            return cls(file_path=file_path)
        return cls(
            file_path=file_path,
            file_size=os.path.getsize(file_path),
            create_time=datetime.fromtimestamp(os.path.getctime(file_path)),
            modify_time=datetime.fromtimestamp(os.path.getmtime(file_path)),
            access_time=datetime.fromtimestamp(os.path.getatime(file_path)),
        )


class LogCleaner:
    """
    清理时间较长的日志，默认保留60天的日志
    """

    def __init__(self, log_dir: str, retention_day: int = 60):
        """
        :param log_dir: 日志目录
        :param retention_day: 保留天数
        """
        self.retention_day = retention_day
        self.log_dir = log_dir
        self.current_time: datetime = datetime.now()
        self.threshold_time: datetime = self.current_time - timedelta(
            days=self.retention_day
        )

    def scan_log(self) -> List[LogInfo]:
        """
        扫描日志目录，返回所有日志文件
        """
        log_files = []
        if os.path.exists(self.log_dir):
            log_files = [
                LogInfo.gen(os.path.join(self.log_dir, file))
                for file in os.listdir(self.log_dir)
                if file.endswith(".log")
            ]
        return log_files

    def judge_is_old_log(self, log_file: LogInfo) -> bool:
        """
        判断日志文件是否过期
        过期标准:
        """
        if log_file.modify_time and log_file.modify_time < self.threshold_time:
            return True
        return False

    def extract_old_log(self) -> List[LogInfo]:
        """
        提取过期的日志文件
        """
        log_files = self.scan_log()

        if not log_files:
            logger.debug("No log files found")
            return []

        logger.debug(
            f"[ExtractOldLogFiles]: scan [{len(log_files)}] logs from [{self.log_dir}]"
        )

        old_log_files = [o for o in log_files if self.judge_is_old_log(o)]

        logger.debug(
            f"[ExtractOldLogFiles]: extract [{len(old_log_files)}] old logs, threshold day [{self.threshold_time}]"
        )

        return old_log_files

    def delete_log(self, log_file: List[LogInfo]):
        """
        删除日志文件
        """
        if log_file:
            logger.debug(f"[DeleteLogFiles]: Start to delete [{len(log_file)}] logs")
            cnt = 0
            for log in log_file:
                try:
                    os.remove(log.file_path)
                    logger.debug(f"[DeleteLogFiles]: Delete log [{log.file_path}]")
                    cnt += 1
                except FileNotFoundError as e:
                    logger.warning(
                        f"[DeleteLogFiles]: Failed to delete log [{log.file_path}], error [{e}]"
                    )

            logger.debug(f"[DeleteLogFiles]: Delete [{cnt}]/[{len(log_file)}] logs")

    def delete_lod_log(self):
        """
        删除过时的日志文件
        """
        old_logs = self.extract_old_log()
        self.delete_log(old_logs)

    @classmethod
    def schedule_run(cls, log_dir: str, retention_day: int = 60):
        """
        启动线程，定时清理日志
        """
        # 创建线程
        interval = 60 * 60 * 24

        def worker():
            while True:
                log_cleaner = LogCleaner(log_dir, retention_day)
                logger.debug(
                    f"pid={os.getpid()} | [ScheduleRun]: Start to run log cleaner, log dir [{log_dir}], retention day [{retention_day}]"
                )
                log_cleaner.delete_lod_log()
                time.sleep(interval)  # 暂停一天

        thread = threading.Thread(target=worker, daemon=True)
        thread.start()



from typing import get_type_hints
import aiohttp
from functools import wraps
from typing import Callable, Any, Awaitable


class BaseClient:
    def __init__(self, session: aiohttp.ClientSession=None, host: str = None):
        self.session = session
        self.host = host

    def open(self):
        self.session = aiohttp.ClientSession()

    async def __aenter__(self) -> "BaseClient":
        self.open()
        return self

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        await self.session.close()

    @staticmethod
    def http_post(endpoint: str):
        """
        HTTP POST请求装饰器，处理通用的请求逻辑
        """

        def decorator(func: Callable[..., Awaitable[Any]]) -> Callable[..., Awaitable[Any]]:
            @wraps(func)
            async def wrapper(client_instance: BaseClient, model: Any, request_id: str):
                # 从原函数的返回类型注解中获取VO类型
                return_type = get_type_hints(func).get("return")
                if return_type is None:
                    raise ValueError(
                        f"Function {func.__name__} must have a return type annotation"
                    )

                url = f"{client_instance.host}{endpoint}"
                headers = {"request_id": request_id}
                json_data = model.model_dump()

                async with client_instance.session.post(
                    url, headers=headers, json=json_data
                ) as response:
                    response.raise_for_status()
                    response_json = await response.json()
                    return return_type(**response_json)

            return wrapper

        return decorator



import os
import psutil
import argparse


def check_memery_maps(process):
    memory_maps = process.memory_maps()
    memory_maps.sort(key=lambda x: x.rss, reverse=True)

    print(f"PID: {process.pid} Memory maps:")
    # 添加表头
    print(f"{'Idx':<3}  {'RSS (MB)':<12} {'Path'}")
    print("-" * 50)

    for idx, item in enumerate(memory_maps):
        path = item.path
        rss_mb = item.rss / 1024 / 1024  # byte to mb
        print(f"{idx:<3}  {rss_mb:<12.2f} {path}")

    total_rss = sum(item.rss for item in memory_maps)
    print(f"Total RSS: {total_rss / 1024 / 1024:.2f} MB")


def check_open_file(process):
    open_files = process.open_files()
    print(f"PID: {process.pid} Open files[{len(open_files)}]:")
    print(f"{'FD':<8} {'Path'}")
    print("-" * 50)
    for item in open_files:
        print(f"{item.fd:<8} {item.path}")


def check_thread(process):
    print(f"PID: {process.pid} Threads[{len(process.threads())}]:")
    for idx, th in enumerate(process.threads()):
        print(idx + 1, th)


def main(pid: int = None):
    process = psutil.Process(pid or os.getpid())
    check_memery_maps(process)
    print("=" * 50)
    check_open_file(process)
    print("=" * 50)
    check_thread(process)


if __name__ == "__main__":
    """
    python -m huibiao_framework.utils.process_check
    """
    parser = argparse.ArgumentParser(
        description="Check system memory maps and open files for a process"
    )
    parser.add_argument(
        "pid",
        nargs="?",
        type=int,
        help="Process ID to check (default: current process)",
    )

    args = parser.parse_args()
    main(args.pid)



import aiohttp

from huibiao_framework.client.data_model.model_resp_vo import ModelBaseRespVo
from huibiao_framework.client.data_model.qa_search import (
    AddQARespVo,
    AddQARequest,
    SearchQARequest,
    SearchAqRespVo,
)
from huibiao_framework.config.config import ClientConfig


class KnowledgeQaSearchClient:
    def __init__(self, session: aiohttp.ClientSession):
        self.base_url = ClientConfig.SEARCH_URL
        self.headers = {"Content-Type": "application/json"}
        self.session = session

    async def add_qa(
        self,
        request_body: AddQARequest,
    ) -> AddQARespVo:
        """
        异步添加QA对到知识库
        """
        url = f"{self.base_url}/qa/add_qa"

        async with self.session.post(
            url, json=request_body.model_dump(), headers=self.headers
        ) as response:
            response.raise_for_status()
            raw_response = await response.json()
            return ModelBaseRespVo[AddQARespVo](**raw_response).result

    async def search_qa(self, request_body: SearchQARequest) -> SearchAqRespVo:
        """
        异步搜索QA对
        """
        url = f"{self.base_url}/qa/search"

        async with self.session.post(
            url, json=request_body.model_dump(), headers=self.headers
        ) as response:
            response.raise_for_status()
            raw_response = await response.json()
            return ModelBaseRespVo[SearchAqRespVo](**raw_response).result



from .abstract_async_file import AbstractAsyncFile
from .async_file import JsonAsyncFile, BytesAsyncFile
from .temp_file import TempAsyncFileWrapper

__all__ = ["AbstractAsyncFile", "JsonAsyncFile", "BytesAsyncFile", "TempAsyncFileWrapper"]
